@@ -2,32 +2,23 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "הערות",
-    "New note" : "הערה חדשה",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
-    "Please wait while new settings are applied…" : "נא להמתין בשעה שההגדרות החדשות מוחלות…",
-    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
     "The last viewed note cannot be accessed. " : "אין גישה לפתק האחרון שנצפה.",
     "The notes folder is not accessible: %s" : "תיקיית הפתקים אינה נגישה: %s",
-    "File error" : "שגיאת קובץ",
     "Encryption Error" : "שגיאת הצפנה",
     "Error" : "שגיאה",
+    "New note" : "הערה חדשה",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
-    "Uncategorized" : "ללא קטגוריה",
-    "Categories" : "קטגוריות",
-    "All notes" : "כל הפתקים",
-    "No search result for {{search}}" : "אין תוצאות לחיפוש אחר {{search}}",
-    "No notes found" : "לא נמצאו הערות",
-    "Delete note" : "מחיקת הערה",
-    "Favorite" : "מועדף",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
     "Settings" : "הגדרות",
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
     "path to notes" : "נתיב לפתקיות",
     "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
+    "All notes" : "כל הפתקים",
+    "Categories" : "קטגוריות",
+    "Delete note" : "מחיקת הערה",
     "Category" : "קטגוריה",
-    "Edit category" : "עריכת קטגוריה",
-    "The note has unsaved changes." : "יש שינויים בהערה שלא נשמרו",
-    "Click here to try again" : "יש ללחוץ כאן כדי לנסות שוב",
+    "Uncategorized" : "ללא קטגוריה",
     "Saving failed!" : "השמירה נכשלה!",
-    "Note saved" : "ההערה נשמרה"
+    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"]
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
