@@ -2,30 +2,42 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Jegyzetek",
-    "New note" : "Új jegyzet",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek!",
-    "Please wait while new settings are applied…" : "Kérlek várj, míg az új beállítások érvénybe lépnek...",
-    "_%n word_::_%n words_" : ["%n szó","%n szó"],
     "The last viewed note cannot be accessed. " : "Az utoljára megtekintett jegyzet nem elérhető.",
-    "File error" : "Fájlhiba",
+    "The notes folder is not accessible: %s" : "A jegyzetek mappa nem elérhető: %s",
     "Encryption Error" : "Titkosítási hiba",
     "Error" : "Hiba",
-    "Uncategorized" : "Kategorizálatlan",
-    "Categories" : "Kategóriák",
-    "All notes" : "Összes jegyzet",
-    "No search result for {{search}} in {{SelectedCategory}}" : "Nincs keresési eredménye a {{search}} itt: {{SelectedCategory}}",
-    "No notes found" : "Nincsenek jegyzetek",
-    "Delete note" : "Jegyzet törlése",
-    "Favorite" : "Kedvenc",
+    "New note" : "Új jegyzet",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek!",
     "Settings" : "Beállítások",
     "Folder to store your notes" : "A jegyzetek tárolási mappája",
     "path to notes" : "Megjegyzés útvonala",
     "File extension for new notes" : "Fájlkiterjesztés új jegyzetekhez",
+    "All notes" : "Összes jegyzet",
+    "Categories" : "Kategóriák",
+    "Today" : "Ma",
+    "Yesterday" : "Tegnap",
+    "This week" : "Ez a hét",
+    "Last week" : "Előző hét",
+    "This month" : "Ez a hónap",
+    "Last month" : "Előző hónap",
+    "Remove from favorites" : "Eltávolítás a kedvencekből",
+    "Add to favorites" : "Hozzáadás a kedvencekhez",
+    "Delete note" : "Jegyzet törlése",
+    "Empty note" : "Üres jegyzet",
+    "Write …" : "Írás ...",
+    "Details" : "Részletek",
+    "Preview" : "Előnézet",
+    "Edit" : "Szerkesztés",
+    "Fullscreen" : "Teljes képernyő",
+    "Set category" : "Kategória beállítása",
     "Category" : "Kategória",
-    "Edit category" : "Kategória szerkesztése",
-    "The note has unsaved changes." : "A jegyzet mentetlen módosításokat tartalmaz.",
-    "Click here to try again" : "Kattints ide az ismételt kísérlethez",
+    "Uncategorized" : "Kategorizálatlan",
     "Saving failed!" : "Mentés sikertelen!",
-    "Note saved" : "Jegyzet mentve"
+    "Last modified: {date}" : "Utoljára módosítva: {date}",
+    "_%n word_::_%n words_" : ["%n szó","%n szó"],
+    "Android app" : "Android alkalmazás",
+    "iOS app" : "iOS alkalmazás",
+    "Updating settings has failed." : "A beállítások frissítése sikertelen.",
+    "Creating new note has failed." : "Új jegyzet létrehozása sikertelen."
 },
 "nplurals=2; plural=(n != 1);");
