@@ -2,35 +2,28 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "ノート",
-    "New note" : "新しいノート",
-    "Updating the note's category has failed. Is the target directory writable?" : "ノートのカテゴリを更新できませんでした。 ターゲットディレクトリは書き込み可能ですか？",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "保存されていないノートがあります。このページから移動するとすべての変更は破棄されます。",
-    "Please wait while new settings are applied…" : "新しい設定が適用されている間お待ちください...",
-    "_%n word_::_%n words_" : ["%n 単語"],
     "The last viewed note cannot be accessed. " : "最後に閲覧したノートにはアクセスできません。",
     "The notes folder is not accessible: %s" : "ノートフォルダーはアクセスできません：%s",
-    "File error" : "ファイルエラー",
     "Encryption Error" : "暗号化エラー",
     "Error" : "エラー",
-    "Uncategorized" : "未分類",
-    "Categories" : "カテゴリ",
-    "All notes" : "すべてのノート",
-    "Search result for \"{{search}}\" in {{SelectedCategory}}" : "{{SelectedCategory}} の \"{{search}}\" の検索結果",
-    "Search result for \"{{search}}\"" : "\"{{search}}\"の検索結果",
-    "No search result for {{search}} in {{SelectedCategory}}" : "{{SelectedCategory}}の{{search}}の検索結果はありません",
-    "No search result for {{search}}" : "{{search}} に関する検索結果はありません。",
-    "No notes found" : "ノートがありません",
-    "Delete note" : "ノートを削除",
-    "Favorite" : "お気に入り",
+    "New note" : "新しいノート",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "保存されていないノートがあります。このページから移動するとすべての変更は破棄されます。",
     "Settings" : "設定",
     "Folder to store your notes" : "ノートを保存するフォルダー",
     "path to notes" : "ノートへのパス",
     "File extension for new notes" : "新しいノートのファイル拡張子",
+    "All notes" : "すべてのノート",
+    "Categories" : "カテゴリ",
+    "Today" : "今日",
+    "This week" : "今週",
+    "Last week" : "先週",
+    "This month" : "今月",
+    "Last month" : "先月",
+    "Delete note" : "ノートを削除",
     "Category" : "カテゴリ",
-    "Edit category" : "カテゴリを編集",
-    "The note has unsaved changes." : "ノートには変更が保存されていません。",
-    "Click here to try again" : "ここをクリックして再試行",
+    "Uncategorized" : "未分類",
     "Saving failed!" : "保存に失敗しました",
-    "Note saved" : "ノートを保存しました"
+    "_%n word_::_%n words_" : ["%n 単語"],
+    "Updating the note's category has failed. Is the target directory writable?" : "ノートのカテゴリを更新できませんでした。 ターゲットディレクトリは書き込み可能ですか？"
 },
 "nplurals=1; plural=0;");
