@@ -2,29 +2,24 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Заметки",
-    "New note" : "Новая заметка",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Заметка не сохранены. Если покинуть страницу, все изменения будут удалены!",
-    "Please wait while new settings are applied…" : "Подождите, пока будут применены новые настройки ...",
-    "_%n word_::_%n words_" : ["%n слово","%n слова","%n слов","%n слов"],
     "The last viewed note cannot be accessed. " : "Не удалось перейти к последней просмотренной заметке",
     "The notes folder is not accessible: %s" : "Папка заметок недоступна: %s",
-    "File error" : "Ошибка файла",
     "Encryption Error" : "Ошибка шифрования",
     "Error" : "Ошибка",
+    "New note" : "Новая заметка",
     "Distraction-free notes and writing" : "Простые заметки и записки",
-    "No search result for {{search}}" : "Нет результатов поиска для {{search}}",
-    "No notes found" : "Записей не найдено",
-    "Delete note" : "Удалить заметку",
-    "Favorite" : "Избранное",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Заметка не сохранены. Если покинуть страницу, все изменения будут удалены!",
     "Settings" : "Параметры",
     "Folder to store your notes" : "Папка для хранения заметок",
     "path to notes" : "путь к заметкам",
     "File extension for new notes" : "Расширения файла для новых заметок",
+    "All notes" : "Все заметки",
+    "Categories" : "Категории",
+    "Delete note" : "Удалить заметку",
     "Category" : "Категория",
-    "Edit category" : "Редактировать категорию",
-    "The note has unsaved changes." : "Изменения в заметке еще не сохранены.",
-    "Click here to try again" : "Нажмите здесь для повтора.",
+    "Uncategorized" : "Без категории",
     "Saving failed!" : "Ошибка при сохранении!",
-    "Note saved" : "Заметка сохранена"
+    "_%n word_::_%n words_" : ["%n слово","%n слова","%n слов","%n слов"],
+    "Updating the note's category has failed. Is the target directory writable?" : "Ошибка обновления категории заметки. Разрешена ли запись в целевую директорию?"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
